<?php
/**
 * Plugin Name: Export Users to CSV for eZbloo
 * Plugin URI:  https://ezbloo.com/
 * Description: A plugin to export all WordPress users with their full name, email, and ID to a CSV file so you can import them into your eZbloo system.
 * Version: 1.1
 * Author: Maximus McCullough
 * Author URI: https://a1websitepro.com/
 */

if (!defined('ABSPATH')) {
    exit; // Prevent direct access
}

// Add a menu item under "Users"
add_action('admin_menu', function () {
    add_users_page('Export Users eZbloo', 'Export Users eZbloo', 'manage_options', 'export-users-csv', 'export_users_csv_page');
});

// Function to display the export page
function export_users_csv_page() {
    ?>
    <div class="wrap">
        <h2>Export Users to CSV for eZbloo</h2>
        <p>Click the button below to download a CSV file of all users, then take this file and upload it to your eZbloo system..</p>
        <a href="<?php echo esc_url(admin_url('admin-post.php?action=export_users_csv')); ?>" class="button button-primary">Download CSV</a>
    </div>
    <?php
}

// Hook into admin-post.php for exporting CSV
add_action('admin_post_export_users_csv', 'export_users_csv');

// Function to handle the CSV export
function export_users_csv() {
    if (!current_user_can('manage_options')) {
        wp_die(__('You do not have permission to access this page.', 'export-users-csv'));
    }

    // Prevent output before headers are sent
    ob_clean();
    nocache_headers();

    // Fetch all users
    $users = get_users();

    // Prepare CSV file headers
    $filename = "users_export_" . date("Y-m-d") . ".csv";
    header("Content-Type: text/csv; charset=UTF-8");
    header("Content-Disposition: attachment; filename=$filename");
    header("Pragma: no-cache");
    header("Expires: 0");

    // Open output buffer
    $output = fopen('php://output', 'w');

    // Add column headers
    fputcsv($output, ['User ID', 'Full Name', 'Email']);

    // Loop through users and add data
    foreach ($users as $user) {
        $full_name = trim($user->first_name . ' ' . $user->last_name);
        if (empty($full_name)) {
            $full_name = $user->display_name; // Fallback to display name if first/last name is empty
        }
        fputcsv($output, [$user->ID, $full_name, $user->user_email]);
    }

    fclose($output);
    exit;
}
?>
